summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.h')
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.h b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.h
index 3b56a1c9..d84019a2 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmpptask.h
@@ -45,7 +45,7 @@ namespace buzz {
// See Task and XmppClient first.
//
// XmppTask is a task that is designed to go underneath XmppClient and be
// useful there. It has a way of finding its XmppClient parent so you
// can have it nested arbitrarily deep under an XmppClient and it can
// still find the XMPP services.
//
@@ -69,7 +69,7 @@ class XmppTask :
public sigslot::has_slots<>
{
public:
- XmppTask(Task * parent, XmppEngine::HandlerLevel level = XmppEngine::HL_NONE);
+ XmppTask(Task * tqparent, XmppEngine::HandlerLevel level = XmppEngine::HL_NONE);
virtual ~XmppTask();
virtual XmppClient * GetClient() const { return client_; }
@@ -78,9 +78,9 @@ public:
protected:
friend class XmppClient;
- XmppReturnStatus SendStanza(const XmlElement * stanza);
- XmppReturnStatus SetResult(const std::string & code);
- XmppReturnStatus SendStanzaError(const XmlElement * element_original,
+ XmppReturntqStatus SendStanza(const XmlElement * stanza);
+ XmppReturntqStatus SetResult(const std::string & code);
+ XmppReturntqStatus SendStanzaError(const XmlElement * element_original,
XmppStanzaError code,
const std::string & text);
@@ -93,7 +93,7 @@ protected:
const XmlElement * NextStanza();
bool MatchResponseIq(const XmlElement * stanza, const Jid & to, const std::string & task_id);
- bool MatchRequestIq(const XmlElement * stanza, const std::string & type, const QName & qn);
+ bool MatchRequestIq(const XmlElement * stanza, const std::string & type, const TQName & qn);
XmlElement *MakeIqResult(const XmlElement * query);
XmlElement *MakeIq(const std::string & type,
const Jid & to, const std::string task_id);
@@ -45,7 +45,7 @@ namespace buzz {
//
// XmppTask is a task that is designed to go underneath XmppClient and be
-// useful there. It has a way of finding its XmppClient parent so you
+// useful there. It has a way of finding its XmppClient tqparent so you
// can have it nested arbitrarily deep under an XmppClient and it can
// still find the XMPP services.